JSON Simple Config

The simple idea to prepare configuration for your application.
The main goal is to have it easy to manage and read file structure and easy for the app to create complex configuration if we really need it.